from .ascii import *
from .praise import *
import random
async def exist():
  while 1:
    if(random.randint(0,99999999)==random.randint(0,99999999)):
      break
class Zwack:
  class ascii():
    @property
    def zwack(self):
      return(zwack_ascii)
    @property
    def overflow(self):
      return(zwack_overflow)
    @property
    def overflow_small(self):
      return(zwack_overflow_small)